---
template: mainpanel
source_form: markdown
name: Credits - Michael Sparks
title: Credits - Michael Sparks
updated: July 2015
---
**Michael Sparks** : <sparks.m@gmail.com>, [blog](http://www.sparkslabs.com/michael/), [twitter](http://twitter.com/sparks_rd), [Linked in](https://www.linkedin.com/pub/michael-sparks/0/1b9/a93)

* Implementation of Lexer, parser, code generation, AST, transforms, code generation, packaging etc
* Language spec
* Website design and implementation

